@@ -5,7 +5,7 @@ from time import sleep
 
 import requests
 
-from constants.core_constants import Constant
+from provider_switch.constants.core_constants import Constant
 from provider_switch.exceptions import BadProviderException, BadRequestException, \
     ExitException
 from provider_switch.helpers.common_helper import CommonHelper
